# mdh_analysis.R
# author: Maggie R. Wagner
# maggie.r.wagner@gmail.com
# If you use or modify this code for your own use,
# please cite the data package from which you downloaded it.
"
Wagner, Maggie R.; Tang, Clara; Salvato, Fernanda; Clouse, Kayla M.; 
Bartlett, Alexandria; Sermons, Shannon; Hoffmann, Mark; 
Balint-Kurti, Peter J.; Kleiner, Manuel (2020). Data from: Microbe-dependent 
heterosis in maize (Version 1.1.0) [Data set]. 
Zenodo. http://doi.org/10.5281/zenodo.3785570
"
####### Load packages #######
library('tidyverse')
library('lme4')
library('lmerTest')
library('car')
library('emmeans')

####### Session info #######
sessionInfo()
"R version 3.5.3 (2019-03-11)
Platform: x86_64-apple-darwin15.6.0 (64-bit)
Running under: macOS Mojave 10.14.6

Matrix products: default
BLAS: /System/Library/Frameworks/Accelerate.framework/Versions/A/Frameworks/vecLib.framework/Versions/A/libBLAS.dylib
LAPACK: /Library/Frameworks/R.framework/Versions/3.5/Resources/lib/libRlapack.dylib

locale:
[1] en_US.UTF-8/en_US.UTF-8/en_US.UTF-8/C/en_US.UTF-8/en_US.UTF-8

attached base packages:
[1] stats     graphics  grDevices utils     datasets  methods   base     

other attached packages:
[1] emmeans_1.4.5   car_3.0-7       carData_3.0-3   forcats_0.5.0  
[5] stringr_1.4.0   dplyr_0.8.5     purrr_0.3.3     readr_1.3.1    
[9] tidyr_1.0.2     tibble_2.1.3    ggplot2_3.3.0   tidyverse_1.3.0
[13] lmerTest_3.1-1  lme4_1.1-21     Matrix_1.2-15  

loaded via a namespace (and not attached):
[1] TH.data_1.0-10      minqa_1.2.4         colorspace_1.4-1   
[4] rio_0.5.16          estimability_1.3    XVector_0.22.0     
[7] fs_1.3.2            rstudioapi_0.11     farver_2.0.3       
[10] fansi_0.4.1         mvtnorm_1.1-0       lubridate_1.7.4    
[13] xml2_1.2.5          codetools_0.2-16    splines_3.5.3      
[16] ade4_1.7-15         jsonlite_1.6.1      phyloseq_1.26.1    
[19] nloptr_1.2.2.1      pbkrtest_0.4-7      broom_0.5.5        
[22] cluster_2.0.7-1     dbplyr_1.4.2        compiler_3.5.3     
[25] httr_1.4.1          backports_1.1.5     assertthat_0.2.1   
[28] cli_2.0.2           tools_3.5.3         igraph_1.2.5       
[31] gtable_0.3.0        glue_1.3.2          reshape2_1.4.3     
[34] Rcpp_1.0.4          Biobase_2.42.0      cellranger_1.1.0   
[37] vctrs_0.2.4         Biostrings_2.50.2   multtest_2.38.0    
[40] ape_5.3             nlme_3.1-137        iterators_1.0.12   
[43] openxlsx_4.1.4      rvest_0.3.5         lifecycle_0.2.0    
[46] MASS_7.3-51.1       zlibbioc_1.28.0     zoo_1.8-7          
[49] scales_1.1.0        hms_0.5.3           parallel_3.5.3     
[52] biomformat_1.10.1   sandwich_2.5-1      rhdf5_2.26.2       
[55] yaml_2.2.1          curl_4.3            stringi_1.4.6      
[58] S4Vectors_0.20.1    foreach_1.5.0       permute_0.9-5      
[61] BiocGenerics_0.28.0 boot_1.3-20         zip_2.0.4          
[64] rlang_0.4.5         pkgconfig_2.0.3     lattice_0.20-38    
[67] Rhdf5lib_1.4.3      labeling_0.3        tidyselect_1.0.0   
[70] plyr_1.8.6          magrittr_1.5        R6_2.4.1           
[73] IRanges_2.16.0      generics_0.0.2      multcompView_0.1-8 
[76] multcomp_1.4-12     DBI_1.1.0           pillar_1.4.3       
[79] haven_2.2.0         foreign_0.8-71      withr_2.1.2        
[82] mgcv_1.8-27         survival_3.1-11     abind_1.4-5        
[85] modelr_0.1.6        crayon_1.3.4        utf8_1.1.4         
[88] grid_3.5.3          readxl_1.3.1        data.table_1.12.8  
[91] vegan_2.5-6         reprex_0.3.0        digest_0.6.25      
[94] xtable_1.8-4        numDeriv_2016.8-1.1 stats4_3.5.3       
[97] munsell_0.5.0      "

####### @@@@@@@ Experiment 1: Sterile vs. SynCom ######
e1 <- read.delim('Expt1_data.txt',sep='\t',header=TRUE) # Load data
e1 <- mutate(e1,Root_g = WholePlant_g-Shoot_g) # calculate root mass
e1 <- mutate(e1,Treatment2=plyr::mapvalues(Treatment,from=c('syncom','sterile'),
                                           to=c('PBS +\nSynCom','Sterile\nPBS')))
####### @@@ Expt 1 - root biomass #######
### Model: root biomass
m1.e1root <- lm(Root_g ~ Genotype*Treatment2,data=e1) # linear model
plot(resid(m1.e1root)~fitted(m1.e1root)) # residuals look good
contrast(emmeans(m1.e1root, 'Genotype',by='Treatment2'),'dunnett',ref=2)

Anova(m1.e1root,type=3) # fit 2-way ANOVA with Type III sums of squares
"Anova Table (Type III tests)

Response: Root_g
Sum Sq Df  F value    Pr(>F)    
(Intercept)        29.4873  1 172.8099 1.144e-14 ***
Genotype            0.5701  2   1.6707  0.203640    
Treatment           2.1632  1  12.6772  0.001149 ** 
Genotype:Treatment  0.4571  2   1.3395  0.275847    
Residuals           5.6309 33             "

pdf(file='e1_dotplot_rootBiomass.pdf',width=4,height=3)
plot(emmeans(m1.e1root,~Genotype,by='Treatment2'),comparisons=TRUE) +
  facet_wrap(~Treatment2,ncol=3)+
  xlab('Root fresh weight (g)') +
  theme_minimal()+
  theme(axis.title.x=element_blank(),axis.title.y=element_text(size=14,face='bold'),
        axis.text.y=element_text(size=14),
        axis.text.x=element_text(size=14,angle=25,vjust=0.9,hjust=0.9),
        strip.background = element_rect(fill='grey77'),
        strip.text=element_text(size=15,face='bold'),
        panel.spacing=unit(2,'line'))+
  coord_flip()
dev.off()

# Effect sizes:
mean(e1$Root_g,na.rm=TRUE) # grand mean = 1.361795 g
emmeans(m1.e1root,~Genotype,by='Treatment2') 
# In sterile conditions:
## B73 = 1.637
## Mo17 = 1.326
## B73xMo17 = 1.691
emmeans(m1.e1root,~Treatment2, by='Genotype') %>% pairs() 
# Reduction due to SynCom:
## B73 =  0.793 +/- 0.223 = 48.4% [s.e.m.= 13.6%]
## Mo17 =  0.806 +/- 0.285 = 60.8% [s.e.m.= 21.5%]
## B73xMo17 =  0.325 +/- 0.230 = 19.2% [13.6%]

####### @@@ Expt 1 - shoot biomass #######
### Model: shoot biomass
m1.e1shoot <- lm(Shoot_g ~ Genotype*Treatment2,data=e1) # linear model
plot(resid(m1.e1shoot)~fitted(m1.e1shoot)) # residuals look good
contrast(emmeans(m1.e1shoot, 'Genotype',by='Treatment2'),'dunnett',ref=2)

Anova(m1.e1shoot,type=3) # fit 2-way ANOVA with Type III sums of squares
"Response: Shoot_g
                  Sum Sq Df  F value   Pr(>F)    
(Intercept)        39.786  1 193.3001 2.37e-15 ***
Genotype            0.104  2   0.2517   0.7790    
Treatment           0.550  1   2.6697   0.1118    
Genotype:Treatment  0.326  2   0.7922   0.4613    
Residuals           6.792 33      "

pdf(file='e1_dotplot_shootBiomass.pdf',width=4,height=3)
plot(emmeans(m1.e1shoot,~Genotype,by='Treatment2'),comparisons=TRUE) +
  facet_wrap(~Treatment2,ncol=3)+
  xlab('Shoot fresh weight (g)') +
  theme_minimal()+
  theme(axis.title.x=element_blank(),axis.title.y=element_text(size=14,face='bold'),
        axis.text.y=element_text(size=14),
        axis.text.x=element_text(size=14,angle=25,vjust=0.9,hjust=0.9),
        strip.background = element_rect(fill='grey77'),
        strip.text=element_text(size=15,face='bold'),
        panel.spacing=unit(2,'line'))+
  coord_flip()
dev.off()

# Effect sizes of SynCom, by genotype:
mean(e1$Shoot_g,na.rm=TRUE) # grand mean = 1.864872 g
emmeans(m1.e1shoot,~Genotype,by='Treatment2') 
# In sterile conditions:
## B73 = 1.90
## Mo17 = 2.03
## B73xMo17 = 2.03
emmeans(m1.e1shoot,~Treatment2, by='Genotype') %>% pairs() # 0.366 g +/- 0.157 (s.e.m.)
# Reduction due to SynCom:
## B73 = 0.400 +/- 0.245 = 21.1% [s.e.m.= 12.9%]
## Mo17 = 0.594 +/- 0.313 = 29.3% [15.4%]
## B73xMo17 = 0.105 +/- 0.252 = 5.2% [12.4%]




####### @@@ Expt 1- permutation tests for strength of midparent heterosis #######
# Calculate midparent heterosis in each treatment:
MPH.e1.root <- emmeans(m1.e1root, 'Genotype',by='Treatment2') %>%
  as.data.frame() %>%
  select(Genotype,Treatment2,emmean) %>%
  pivot_wider(names_from=Genotype,values_from=emmean) %>%
  mutate(inbredMean = (B73+Mo17)/2,
         MPH = (B73xMo17-inbredMean)/inbredMean)
MPH.e1.shoot <- emmeans(m1.e1shoot, 'Genotype',by='Treatment2') %>%
  as.data.frame() %>%
  select(Genotype,Treatment2,emmean) %>%
  pivot_wider(names_from=Genotype,values_from=emmean) %>%
  mutate(inbredMean = (B73+Mo17)/2,
         MPH = (B73xMo17-inbredMean)/inbredMean)
# Calculate "Delta MPH" (MPH in nonsterile - MPH in sterile)
# Positive dMPH = heterosis was reduced in sterile conditions
dMPH.e1.root <- filter(MPH.e1.root,str_detect(Treatment2,'SynCom'))$MPH - 
  filter(MPH.e1.root,str_detect(Treatment2,'Sterile'))$MPH
dMPH.e1.shoot <- filter(MPH.e1.shoot,str_detect(Treatment2,'SynCom'))$MPH - 
  filter(MPH.e1.shoot,str_detect(Treatment2,'Sterile'))$MPH
# IS this significantly higher than 0? 
# Permute "treatment" to generate null distribution of dMPH
# Followed by one-tail test

nPerm = 999
for (i in 1:nPerm) {
  print(paste0('Beginning simulation number ',i))
  set.seed(i) # seed the RNG
  # permute Treatment:
  e1.perm <- mutate(e1,Treatment.perm = sample(Treatment,size=length(Treatment),replace=FALSE))
  # fit same models used above:
  perm.m1.e1root <- lm(Root_g ~ Genotype*Treatment.perm,data=e1.perm) # linear model
  perm.m1.e1shoot <- lm(Shoot_g ~ Genotype*Treatment.perm,data=e1.perm) # linear model
  # use EM means to calculate MPH for this permutation
  perm.MPH.e1root <- emmeans(perm.m1.e1root, 'Genotype',by='Treatment.perm') %>%
    as.data.frame() %>%
    select(Genotype,Treatment.perm,emmean) %>%
    pivot_wider(names_from=Genotype,values_from=emmean) %>%
    mutate(inbredMean = (B73+Mo17)/2,
           MPH = (B73xMo17-inbredMean)/inbredMean)
  perm.MPH.e1shoot <- emmeans(perm.m1.e1shoot, 'Genotype',by='Treatment.perm') %>%
    as.data.frame() %>%
    select(Genotype,Treatment.perm,emmean) %>%
    pivot_wider(names_from=Genotype,values_from=emmean) %>%
    mutate(inbredMean = (B73+Mo17)/2,
           MPH = (B73xMo17-inbredMean)/inbredMean)
  # calculate delta MPH for this permutation
  perm.dMPH.e1root <- filter(perm.MPH.e1root,Treatment.perm=='syncom')$MPH - 
    filter(perm.MPH.e1root,Treatment.perm=='sterile')$MPH
  perm.dMPH.e1shoot <- filter(perm.MPH.e1shoot,Treatment.perm=='syncom')$MPH - 
    filter(perm.MPH.e1shoot,Treatment.perm=='sterile')$MPH
  # save results
  if (i==1) {perm.dMPH.e1 <- data.frame('perm.dMPH.root'=perm.dMPH.e1root,'perm.dMPH.shoot'=perm.dMPH.e1shoot)}
  else {perm.dMPH.e1 <- rbind(perm.dMPH.e1, data.frame('perm.dMPH.root'=perm.dMPH.e1root,'perm.dMPH.shoot'=perm.dMPH.e1shoot))}
}
# How many of the permuted dMPH values are at least as large as the observed value?
filter(perm.dMPH.e1,perm.dMPH.root>=dMPH.e1.root) %>% dim() # roots: only 2 --> P = 0.002
filter(perm.dMPH.e1,perm.dMPH.shoot>=dMPH.e1.shoot) %>% dim() # shoots: 56 --> P = 0.056

# Plot the results:
pdf(file='e1_perm_root.pdf',width=4,height=3)
ggplot(perm.dMPH.e1, aes(x=perm.dMPH.root))+
  geom_histogram()+
  geom_vline(xintercept=dMPH.e1.root,color='red',size=1.5,linetype='dashed')+
  ggtitle('Root biomass: SynCom vs. sterile')+
  ylab('')+xlab('MPH in nonsterile conditions \n - MPH in sterile conditions')+
  theme_classic()+
  theme(axis.text=element_text(size=12),axis.title=element_text(size=14))
dev.off()

pdf(file='e1_perm_shoot.pdf',width=4,height=3)
ggplot(perm.dMPH.e1, aes(x=perm.dMPH.shoot))+
  geom_histogram()+
  geom_vline(xintercept=dMPH.e1.shoot,color='red',size=1.5,linetype='dashed')+
  ggtitle('Shoot biomass: SynCom vs. sterile')+
  ylab('')+xlab('MPH in nonsterile conditions \n - MPH in sterile conditions')+
  theme_classic()+
  theme(axis.text=element_text(size=12),axis.title=element_text(size=14))
dev.off()



# Clean up:
rm(perm.dMPH.e1,perm.dMPH.e1root,perm.m1.e1root,perm.MPH.e1root,perm.dMPH.e1shoot,perm.m1.e1shoot,perm.MPH.e1shoot)
rm(MPH.e1.root,MPH.e1.shoot,dMPH.e1.root,dMPH.e1.shoot)
####### @@@ SynCom in vitro germination assay (Tang) #######
datagermination <- read.delim("SynCom_germination_data.txt")

pdf(file='SynCom_germination.pdf',width=6,height=5)
group_by(datagermination,Genotype,Community) %>%
  summarize(Rate4 = mean(Rate), Rate4.SE = sd(Rate)/sqrt(length(Rate)),
            Rate11 = mean(Rate_11), Rate11.SE = sd(Rate_11)/sqrt(length(Rate_11))) %>%
  ggplot(.,aes(x=Genotype,fill=Genotype,y=Rate4))+
  facet_wrap(~Community)+
  geom_bar(stat='identity',position=position_dodge())+
  geom_errorbar(position=position_dodge(),aes(ymin=Rate4-Rate4.SE,ymax=Rate4+Rate4.SE))+
  ylab('Proportion germinating after 4 days')+
  theme_classic()+
  theme(axis.title.x = element_blank(),axis.text.x=element_blank())+
  theme(strip.background=element_rect(fill='grey77'),strip.text=element_text(face='bold',size=14))+
  theme(legend.title=element_blank(),legend.text=element_text(size=14))+
  theme(axis.title.y=element_text(face='bold',size=15))+
scale_fill_manual(values=c('red','purple','blue'))
dev.off()

#define interaction term
inter<- with(datagermination, interaction(Genotype, Community))

#test for diff genotype
kruskal.test(Rate~ Genotype, data=datagermination)
#test for diff nutrient media
kruskal.test(Rate~ Nutrient, data=datagermination)
# test for difference in syncom
kruskal.test(Rate~ Community, data=datagermination)
# interaction ##
kruskal.test(datagermination$Rate, inter)

# multiple comparisons using the wilcoxon rank sum test
pairwise.wilcox.test(datagermination$Rate, inter, p.adjust.method = "BH", paired= FALSE)

####### $$$$$$$ Experiment 2: Sterile vs. Killed Slurry vs. Live Slurry ######
e2 <- read.delim('Expt2_data.txt',sep='\t',header=TRUE) # Load data
e2 <- mutate(e2,Root_g = Total_mass_g - Shoot_mass_g) %>% # calculate root mass
  mutate(Block=factor((str_remove(PlantID,'[BXMCLK]')))) %>%
  mutate(Treatment2=plyr::mapvalues(Treatment,from=c('live','killed','control'),
                                    to=c('Live soil\nslurry','Killed soil\nslurry','Sterile\nPBS')))
####### $$$ Expt 2 - germination #######
### Plot germination success
# count up germinants in each treatment/genotype:
e2.germ <- table(e2$Germ,e2$Treatment2,e2$Genotype) %>% as.data.frame() %>%
  rename(Germ=Var1,Treatment=Var2,Genotype=Var3)
# calculate proportions:
e2.germ <- spread(e2.germ,key=Germ,value=Freq) %>% mutate(pGerm=(Y/(Y+N)))
# plot:
pdf(file='e2_barplot_germination.pdf',width=5,height=3)
ggplot(e2.germ,aes(x=Treatment,y=pGerm,fill=Genotype))+
  geom_bar(stat='identity',width=0.6,position=position_dodge(width=0.7))+
  theme_classic()+
  ylab('Proportion germinating')+
  scale_fill_manual(values=c('red','purple','blue'))+
  theme(axis.title.x=element_blank(),legend.title=element_blank(),
        axis.text=element_text(size=14),legend.text=element_text(size=14),
        axis.title.y=element_text(size=15,face='bold'),
        legend.position='top')
dev.off()

### Fisher's exact tests of germination success ###
## Live soil slurry
# B73 vs hybrid **
fisher.test(filter(e2.germ,Genotype!='Mo17',str_detect(Treatment,'Live')) %>% select(Y,N),simulate.p.value=TRUE)
# Mo17 vs hybrid ***
fisher.test(filter(e2.germ,Genotype!='B73',str_detect(Treatment,'Live')) %>% select(Y,N),simulate.p.value=TRUE)
## Killed soil slurry
# B73 vs hybrid - ns
fisher.test(filter(e2.germ,Genotype!='Mo17',str_detect(Treatment,'Killed')) %>% select(Y,N),simulate.p.value=TRUE)
# Mo17 vs hybrid - ns
fisher.test(filter(e2.germ,Genotype!='B73',str_detect(Treatment,'Killed')) %>% select(Y,N),simulate.p.value=TRUE)
## Sterile control
# B73 vs hybrid - ns
fisher.test(filter(e2.germ,Genotype!='Mo17',str_detect(Treatment,'PBS')) %>% select(Y,N),simulate.p.value=TRUE)
# Mo17 vs hybrid **
fisher.test(filter(e2.germ,Genotype!='B73',str_detect(Treatment,'PBS')) %>% select(Y,N),simulate.p.value=TRUE)

####### $$$ Expt 2 - root biomass #######
### Model: root biomass
m1.e2root <- lmer(Root_g ~ Genotype*Treatment2 + (1|Block),data=e2) # linear model
plot(resid(m1.e2root)~fitted(m1.e2root)) # residuals look fine
contrast(emmeans(m1.e2root, 'Genotype',by='Treatment2'),'dunnett',ref=2)

anova(m1.e2root,ddf='Kenward-Roger') # fit 2-way ANOVA with Type III sums of squares
"Type III Analysis of Variance Table with Kenward-Roger's method
                      Sum Sq  Mean Sq NumDF  DenDF F value  Pr(>F)  
Genotype           0.059742 0.029871     2 61.688  1.0942 0.34120  
Treatment          0.201547 0.100774     2 74.862  3.7008 0.02933 *
Genotype:Treatment 0.239259 0.059815     4 71.190  2.1963 0.07803 .
"
ranova(m1.e2root)
pdf(file='e2_dotplot_rootBiomass.pdf',width=5,height=3)
plot(emmeans(m1.e2root,~Genotype,by='Treatment2'),comparisons=TRUE) +
  facet_wrap(~Treatment2,ncol=3)+
  xlab('Root fresh weight (g)') +
  theme_minimal()+
  theme(axis.title.x=element_blank(),axis.title.y=element_text(size=14,face='bold'),
        axis.text.y=element_text(size=14),
        axis.text.x=element_text(size=14,angle=25,vjust=0.9,hjust=0.9),
        strip.background = element_rect(fill='grey77'),
        strip.text=element_text(size=15,face='bold'),
        panel.spacing=unit(2,'line'))+
  coord_flip()
dev.off()

####### $$$ Expt 2 - shoot biomass #######
### Model: shoot biomass
m1.e2shoot <- lmer(Shoot_mass_g ~ Genotype*Treatment2 + (1|Block),data=e2) # linear model
plot(resid(m1.e2shoot)~fitted(m1.e2shoot)) # residuals look good
contrast(emmeans(m1.e2shoot, 'Genotype',by='Treatment2'),'dunnett',ref=2)

anova(m1.e2shoot,ddf='Kenward-Roger') # fit 2-way ANOVA with Type III sums of squares
"Type III Analysis of Variance Table with Kenward-Roger's method
Sum Sq Mean Sq NumDF DenDF F value    Pr(>F)    
Genotype           1.87290 0.93645     2 60.08 10.4599 0.0001265 ***
Treatment          0.00229 0.00115     2 78.05  0.0128 0.9872423    
Genotype:Treatment 0.20846 0.05211     4 73.75  0.5834 0.6755951 
"
ranova(m1.e2shoot)

pdf(file='e2_dotplot_shootBiomass.pdf',height=3,width=5)
plot(emmeans(m1.e2shoot,~Genotype,by='Treatment2'),comparisons=TRUE) +
  facet_wrap(~Treatment2,ncol=3)+
  xlab('Shoot fresh weight (g)') +
  theme_minimal()+
  theme(axis.title.x=element_blank(),axis.title.y=element_text(size=14,face='bold'),
        axis.text.y=element_text(size=14),
        axis.text.x=element_text(size=14,angle=25,vjust=0.9,hjust=0.9),
        strip.background = element_rect(fill='grey77'),
        strip.text=element_text(size=15,face='bold'),
        panel.spacing=unit(2,'line'))+
  coord_flip()
dev.off()

####### $$$ Expt 2 - permutation tests for strength of midparent heterosis #######
# Calculate midparent heterosis in each treatment:
MPH.e2.root <- emmeans(m1.e2root, 'Genotype',by='Treatment2') %>%
  as.data.frame() %>%
  select(Genotype,Treatment2,emmean) %>%
  pivot_wider(names_from=Genotype,values_from=emmean) %>%
  mutate(inbredMean = (B73+Mo17)/2,
         MPH = (B73xMo17-inbredMean)/inbredMean)
MPH.e2.shoot <- emmeans(m1.e2shoot, 'Genotype',by='Treatment2') %>%
  as.data.frame() %>%
  select(Genotype,Treatment2,emmean) %>%
  pivot_wider(names_from=Genotype,values_from=emmean) %>%
  mutate(inbredMean = (B73+Mo17)/2,
         MPH = (B73xMo17-inbredMean)/inbredMean)
# Calculate "Delta MPH" (MPH in nonsterile - MPH in each sterile treatment)
# Positive dMPH = heterosis was reduced in sterile conditions
dMPH.e2.killed.root <- filter(MPH.e2.root,str_detect(Treatment2,'Live'))$MPH - 
  filter(MPH.e2.root,str_detect(Treatment2,'Killed'))$MPH
dMPH.e2.killed.shoot <- filter(MPH.e2.shoot,str_detect(Treatment2,'Live'))$MPH - 
  filter(MPH.e2.shoot,str_detect(Treatment2,'Killed'))$MPH
dMPH.e2.sterile.root <- filter(MPH.e2.root,str_detect(Treatment2,'Live'))$MPH - 
  filter(MPH.e2.root,str_detect(Treatment2,'PBS'))$MPH
dMPH.e2.sterile.shoot <- filter(MPH.e2.shoot,str_detect(Treatment2,'Live'))$MPH - 
  filter(MPH.e2.shoot,str_detect(Treatment2,'PBS'))$MPH
# IS this significantly higher than 0? 
# Permute "treatment" to generate null distribution of dMPH
# Followed by one-tail test

nPerm = 999
for (i in 1:nPerm) {
  print(paste0('Beginning simulation number ',i))
  set.seed(i) # seed the RNG
  for (treat in c('control','killed')) {
    # subset to only include live + 1 sterile treatment, then permute Treatment:
    e2.perm <- filter(e2,Treatment%in%c('live',treat)) %>%
              mutate(Treatment.perm = sample(Treatment,size=length(Treatment),replace=FALSE))
    # fit same models used above:
    perm.m1.e2root <- lmer(Root_g ~ Genotype*Treatment.perm + (1|Block),data=e2.perm) # linear mixed model
    perm.m1.e2shoot <- lmer(Shoot_mass_g ~ Genotype*Treatment.perm + (1|Block),data=e2.perm) # linear mixed model
    # use EM means to calculate MPH for this permutation
    perm.MPH.e2root <- emmeans(perm.m1.e2root, 'Genotype',by='Treatment.perm') %>%
      as.data.frame() %>%
      select(Genotype,Treatment.perm,emmean) %>%
      pivot_wider(names_from=Genotype,values_from=emmean) %>%
      mutate(inbredMean = (B73+Mo17)/2,
             MPH = (B73xMo17-inbredMean)/inbredMean)
    perm.MPH.e2shoot <- emmeans(perm.m1.e2shoot, 'Genotype',by='Treatment.perm') %>%
      as.data.frame() %>%
      select(Genotype,Treatment.perm,emmean) %>%
      pivot_wider(names_from=Genotype,values_from=emmean) %>%
      mutate(inbredMean = (B73+Mo17)/2,
             MPH = (B73xMo17-inbredMean)/inbredMean)
    # calculate delta MPH for this permutation
    perm.dMPH.e2root <- filter(perm.MPH.e2root,Treatment.perm=='live')$MPH - 
      filter(perm.MPH.e2root,Treatment.perm==treat)$MPH
    perm.dMPH.e2shoot <- filter(perm.MPH.e2shoot,Treatment.perm=='live')$MPH - 
      filter(perm.MPH.e2shoot,Treatment.perm==treat)$MPH
    # save results
    if (i==1 & treat=='control') {perm.dMPH.e2 <- data.frame('contrast'=treat, 'perm.dMPH.root'=perm.dMPH.e2root,'perm.dMPH.shoot'=perm.dMPH.e2shoot)}
    else {perm.dMPH.e2 <- rbind(perm.dMPH.e2, data.frame('contrast'=treat, 'perm.dMPH.root'=perm.dMPH.e2root,'perm.dMPH.shoot'=perm.dMPH.e2shoot))}
  }
}
# How many of the permuted dMPH values are at least as large as the observed value?
## Killed slurry vs. live slurry:
filter(perm.dMPH.e2,contrast=='killed',perm.dMPH.root>=dMPH.e2.killed.root) %>% dim() # roots: 7 --> P = 0.007
filter(perm.dMPH.e2,contrast=='killed',perm.dMPH.shoot>=dMPH.e2.killed.shoot) %>% dim() # shoots: 190 --> P = 0.19
## Sterile buffer control vs. live slurry:
filter(perm.dMPH.e2,contrast=='control',perm.dMPH.root>=dMPH.e2.sterile.root) %>% dim() # roots: 68 --> P = 0.068
filter(perm.dMPH.e2,contrast=='control',perm.dMPH.shoot>=dMPH.e2.sterile.shoot) %>% dim() # shoots: 244 --> P = 0.244

# Plot the results:
pdf(file='e2_perm_root_killed.pdf',width=4,height=3)
filter(perm.dMPH.e2,contrast=='killed') %>%
ggplot(aes(x=perm.dMPH.root))+
  geom_histogram()+
  geom_vline(xintercept=dMPH.e2.killed.root,color='red',size=1.5,linetype='dashed')+
  ggtitle('Root biomass: Live slurry vs. killed slurry')+
  ylab('')+xlab('MPH in nonsterile conditions \n - MPH in sterile conditions')+
  theme_classic()+
  theme(axis.text=element_text(size=12),axis.title=element_text(size=14))
dev.off()

pdf(file='e2_perm_shoot_killed.pdf',width=4,height=3)
filter(perm.dMPH.e2,contrast=='killed') %>%
  ggplot(aes(x=perm.dMPH.shoot))+
  geom_histogram()+
  geom_vline(xintercept=dMPH.e2.killed.shoot,color='red',size=1.5,linetype='dashed')+
  ggtitle('Shoot biomass: Live slurry vs. killed slurry')+
  ylab('')+xlab('MPH in nonsterile conditions \n - MPH in sterile conditions')+
  theme_classic()+
  theme(axis.text=element_text(size=12),axis.title=element_text(size=14))
dev.off()

pdf(file='e2_perm_root_control.pdf',width=4,height=3)
filter(perm.dMPH.e2,contrast=='control') %>%
  ggplot(aes(x=perm.dMPH.root))+
  geom_histogram()+
  geom_vline(xintercept=dMPH.e2.killed.root,color='red',size=1.5,linetype='dashed')+
  ggtitle('Root biomass: Live slurry vs. sterile PBS')+
  ylab('')+xlab('MPH in nonsterile conditions \n - MPH in sterile conditions')+
  theme_classic()+
  theme(axis.text=element_text(size=12),axis.title=element_text(size=14))
dev.off()

pdf(file='e2_perm_shoot_control.pdf',width=4,height=3)
filter(perm.dMPH.e2,contrast=='control') %>%
  ggplot(aes(x=perm.dMPH.shoot))+
  geom_histogram()+
  geom_vline(xintercept=dMPH.e2.killed.shoot,color='red',size=1.5,linetype='dashed')+
  ggtitle('Shoot biomass: Live slurry vs. sterile PBS')+
  ylab('')+xlab('MPH in nonsterile conditions \n - MPH in sterile conditions')+
  theme_classic()+
  theme(axis.text=element_text(size=12),axis.title=element_text(size=14))
dev.off()



# Clean up:
rm(perm.dMPH.e2,perm.dMPH.e2root,perm.m1.e2root,perm.MPH.e2root,perm.dMPH.e2shoot,perm.m1.e2shoot,perm.MPH.e2shoot)
rm(MPH.e2.root,MPH.e2.shoot,dMPH.e2.killed.root,dMPH.e2.killed.shoot,dMPH.e2.sterile.root,dMPH.e2.sterile.shoot)
####### &&&&&&& Experiment 3: On-farm soil fumigation #######
e3 <- read.delim('Expt3_germ_growth.txt',sep='\t',header=TRUE,na.strings = c('NA','','np','nm')) %>%
  #filter(Treatment %in% c('AITC_steam','chloropicrin','control')) %>%
  mutate(Treatment=factor(Treatment),
         Treatment2=plyr::mapvalues(Treatment,from=c('AITC_only','AITC_steam','chloropicrin','control','steam_only'),
                                    to=c(' AITC\nonly','AITC +\nsteam','chloropicrin','untreated\ncontrol',' steam\nonly')))
e3.biomass <- read.delim('Expt3_biomass.txt',sep='\t',header=TRUE) %>%
  merge(.,e3,by='PlantID',all.x=TRUE,all.y=FALSE)

####### &&& Expt 3 - germination #######
### Plot germination success
# count up germinants in each treatment/genotype on each date:
# Barplot:
pdf(file='SuppFig7_e3_barplot_germination.pdf',width=9,height=6)
select(e3,PlantID,Genotype,Treatment2,Block,Sub_block,starts_with('Germ')) %>%
  pivot_longer(starts_with('Germ'),names_to='Date',values_to='nGerm') %>%
  count(Genotype,Treatment2,Date,nGerm) %>%
  filter(!is.na(nGerm)) %>%
  mutate(Germinants = nGerm*n,Date=str_remove(Date,'Germ_')) %>%
  group_by(Genotype,Treatment2,Date) %>%
  summarize(pGerm = sum(Germinants)/(2*sum(n))) %>%  # denominator = total number of seeds planted per genotype*treatment combination (after excluding NAs)
  ggplot(.,aes(x=Genotype,y=pGerm,fill=Genotype))+
  facet_grid(Date~Treatment2)+
  geom_bar(stat='identity')+
  theme_classic()+
  ylab('Proportion germinating')+
  coord_cartesian(ylim=c(0,1))+
  scale_fill_manual(values=c('red','purple','blue'))+
  theme(axis.title.x=element_blank(),legend.title=element_blank(),
        axis.text=element_text(size=14),legend.text=element_text(size=14),
        axis.text.x=element_text(angle=25,vjust=0.9,hjust=0.9),
        strip.background=element_rect(fill='grey77'),strip.text=element_text(size=15,face='bold'),
        axis.title.y=element_text(size=17,face='bold'),panel.grid.major.y=element_line(color='grey91'),
        panel.grid.minor.y=element_line(color='grey91'),legend.position='top',
        panel.spacing=unit(1.5,'line'))
dev.off()

### Fisher's exact test
e3.germ <- select(e3,PlantID,Genotype,Treatment2,Block,Sub_block,starts_with('Germ')) %>%
  pivot_longer(starts_with('Germ'),names_to='Date',values_to='nGerm') %>%
  count(Genotype,Treatment2,Date,nGerm) %>%
  filter(!is.na(nGerm)) %>%
  mutate(Germinants = nGerm*n,Date=str_remove(Date,'Germ_')) %>%
  group_by(Genotype,Treatment2,Date) %>%
  summarize(Total=2*sum(n),Germinants=sum(Germinants), nonGerminants = 2*sum(n)-sum(Germinants)) 

# Get P values for Fisher's Exact Test for germination proportions in each Treatment, each date
for (i in c(1:5)) {
  treatment <- levels(e3.germ$Treatment2)[i]
  for (j in c(1:3)) {
    date <- c('05_dap','08_dap','12_dap')[j]
    germdata <- filter(e3.germ,Treatment2==treatment,Date==date) %>% select(Genotype,Germinants,nonGerminants) %>% as.data.frame()
    B.fishertest <- fisher.test(filter(germdata,Genotype!='Mo17') %>% select(Germinants, nonGerminants))
    M.fishertest <- fisher.test(filter(germdata,Genotype!='B73') %>% select(Germinants, nonGerminants))
    res <- data.frame('Treatment'=treatment,'Date'=date,'B73_vs_hyb'=B.fishertest$p.value,'Mo17_vs_hyb'=M.fishertest$p.value)
    if (i==1 & j==1) {allRes.e3germ <- res}
    else {allRes.e3germ <- rbind(allRes.e3germ,res)} 
  }
}

####### &&& Expt 3 - root biomass #######
m1.e3root <- lmer(root_dry_weight_g~Genotype*Treatment2 + (1|Block) + (1|Sub_block), data=e3.biomass)
plot(residuals(m1.e3root)~fitted(m1.e3root)) # beautiful
contrast(emmeans(m1.e3root, 'Genotype',by='Treatment2'),'dunnett',ref=2)

anova(m1.e3root,ddf='Kenward-Roger')
"Type III Analysis of Variance Table with Kenward-Roger's method
                      Sum Sq  Mean Sq NumDF  DenDF F value  Pr(>F)    
Genotype            0.118545 0.059272     2 398.16 55.5819 < 2e-16 ***
Treatment2          0.008104 0.004052     2   9.00  3.7997 0.06364 .  
Genotype:Treatment2 0.006964 0.001741     4 398.06  1.6326 0.16520   "
as.data.frame(anova(m1.e3root)) # get exact P-value
ranova(m1.e3root)
"                npar logLik     AIC    LRT Df Pr(>Chisq)  
<none>            12 918.78 -1813.6                       
(1 | Block)       11 916.05 -1810.1 5.4701  1    0.01934 *
(1 | Sub_block)   11 918.42 -1814.8 0.7236  1    0.39495  "

pdf(file='e3_dotplot_rootBiomass.pdf',width=5,height=4)
plot(emmeans(m1.e3root,~Genotype,by='Treatment2'),comparisons=TRUE) +
  facet_wrap(~Treatment2,ncol=3)+
  xlab('Root dry weight (g)') +
  theme_minimal()+
  theme(axis.title.x=element_blank(),axis.title.y=element_text(size=14,face='bold'),
        axis.text.y=element_text(size=14),
        axis.text.x=element_text(size=14,angle=25,vjust=0.9,hjust=0.9),
        strip.background = element_rect(fill='grey77'),
        strip.text=element_text(size=15,face='bold'),
        panel.spacing = unit(1.5,'line'))+
  coord_flip()
dev.off()

####### &&& Expt 3 - shoot biomass #######
m1.e3shoot <- lmer(shoot_dry_weight_g~Genotype*Treatment2 + (1|Block) + (1|Sub_block), data=e3.biomass)
plot(residuals(m1.e3shoot)~fitted(m1.e3shoot)) # nice
contrast(emmeans(m1.e3shoot, 'Genotype',by='Treatment2'),'dunnett',ref=2)

anova(m1.e3shoot,ddf='Kenward-Roger')
"Type III Analysis of Variance Table with Kenward-Roger's method
                    Sum Sq Mean Sq NumDF  DenDF  F value    Pr(>F)    
Genotype            9.4786  4.7393     2 398.88 235.6280 < 2.2e-16 ***
Treatment2          0.2105  0.1053     2   9.00   5.2333 0.0310750 *  
Genotype:Treatment2 0.4212  0.1053     4 398.78   5.2356 0.0004047 *** "
as.data.frame(anova(m1.e3shoot))
ranova(m1.e3shoot)

pdf(file='e3_dotplot_shootBiomass.pdf',width=5,height=4)
plot(emmeans(m1.e3shoot,~Genotype,by='Treatment2'),comparisons=TRUE) +
  facet_wrap(~Treatment2,ncol=3)+
  xlab('Shoot dry weight (g)') +
  theme_minimal()+
  theme(axis.title.x=element_blank(),axis.title.y=element_text(size=14,face='bold'),
        axis.text.y=element_text(size=14),
        axis.text.x=element_text(size=14,angle=25,vjust=0.9,hjust=0.9),
        strip.background = element_rect(fill='grey77'),
        strip.text=element_text(size=15,face='bold'),
        panel.spacing = unit(1.5,'line'))+
  coord_flip()
dev.off()

####### &&& Expt 3 - leaf number #######
e3.leafN <- select(e3,Genotype,starts_with('Leaf_Number'),PlantID,Treatment,Treatment2,Block,Sub_block) %>%
  pivot_longer(starts_with('Leaf_Number'),names_to='Date',values_to='N_leaves') %>%
  mutate(Date=str_remove(Date,'Leaf_Number_'))

m1.e3leafN <- lmer(N_leaves~Genotype*Treatment2*Date + (1|PlantID) + (1|Block) + (1|Sub_block), data=e3.leafN)
plot(residuals(m1.e3leafN)~fitted(m1.e3leafN)) # looks good
contrast(emmeans(m1.e3leafN, 'Genotype',by='Treatment2'),'dunnett',ref=2)

anova(m1.e3leafN,ddf='Kenward-Roger')
"Type III Analysis of Variance Table with Kenward-Roger's method
                          Sum Sq Mean Sq NumDF  DenDF    F value    Pr(>F)    
Genotype                  117.29   58.65     2 657.87   470.1872 < 2.2e-16 ***
Treatment2                  0.96    0.24     4  15.00     1.9200    0.1593    
Date                     2160.68 2160.68     1 768.40 17322.8766 < 2.2e-16 ***
Genotype:Treatment2         1.56    0.19     8 657.16     1.5627    0.1326    
Genotype:Date              47.14   23.57     2 768.42   188.9828 < 2.2e-16 ***
Treatment2:Date             5.07    1.27     4 768.06    10.1586  5.12e-08 ***
Genotype:Treatment2:Date    1.14    0.14     8 768.08     1.1386    0.3347      "
ranova(m1.e3leafN) %>% as.data.frame()

pdf(file='e3_dotplot_LeafN.pdf',width=9,height=4)
plot(emmeans(m1.e3leafN,~Genotype,by='Treatment2'),comparisons=TRUE) +
  facet_wrap(~Treatment2,ncol=5)+
  xlab('Number of leaves') +
  theme_minimal()+
  theme(axis.title.x=element_blank(),axis.title.y=element_text(size=14,face='bold'),
        axis.text.y=element_text(size=14),
        axis.text.x=element_text(size=14,angle=25,vjust=0.9,hjust=0.9),
        strip.background = element_rect(fill='grey77'),
        strip.text=element_text(size=15,face='bold'),
        panel.spacing = unit(1.5,'line'))+
  coord_flip()
dev.off()

####### &&& Expt 3 - height #######
e3.height <- select(e3,Genotype,starts_with('Height'),PlantID,Treatment,Treatment2,Block,Sub_block) %>%
  pivot_longer(starts_with('Height'),names_to='Date',values_to='Height_cm') %>%
  mutate(Date=str_remove(Date,'Height_cm_'))

m1.e3height <- lmer(Height_cm~Genotype*Treatment2*Date + (1|PlantID) + (1|Block) + (1|Sub_block), data=e3.height)
plot(residuals(m1.e3height)~fitted(m1.e3height)) # looks good
contrast(emmeans(m1.e3height, 'Genotype',by='Treatment2'),'dunnett',ref=2) # Dunnett's test

anova(m1.e3height,ddf='Kenward-Roger')
ranova(m1.e3height)

pdf(file='e3_dotplot_Height.pdf',width=9,height=4)
plot(emmeans(m1.e3height,~Genotype,by='Treatment2'),comparisons=TRUE) +
  facet_wrap(~Treatment2,ncol=5)+
  xlab('Height (cm)') +
  theme_minimal()+
  theme(axis.title.x=element_blank(),axis.title.y=element_text(size=14,face='bold'),
        axis.text.y=element_text(size=14),
        axis.text.x=element_text(size=14,angle=25,vjust=0.9,hjust=0.9),
        strip.background = element_rect(fill='grey77'),
        strip.text=element_text(size=15,face='bold'),
        panel.spacing = unit(1.5,'line'))+
  coord_flip()
dev.off()

####### $$$ Expt 3 - permutation tests for strength of midparent heterosis - biomass #######
# Calculate midparent heterosis in each treatment:
MPH.e3.root <- emmeans(m1.e3root, 'Genotype',by='Treatment2') %>%
  as.data.frame() %>%
  select(Genotype,Treatment2,emmean) %>%
  pivot_wider(names_from=Genotype,values_from=emmean) %>%
  mutate(inbredMean = (B73+Mo17)/2,
         MPH = (B73xMo17-inbredMean)/inbredMean)
MPH.e3.shoot <- emmeans(m1.e3shoot, 'Genotype',by='Treatment2') %>%
  as.data.frame() %>%
  select(Genotype,Treatment2,emmean) %>%
  pivot_wider(names_from=Genotype,values_from=emmean) %>%
  mutate(inbredMean = (B73+Mo17)/2,
         MPH = (B73xMo17-inbredMean)/inbredMean)
# Calculate "Delta MPH" (MPH in nonsterile - MPH in each sterile treatment)
# Positive dMPH = heterosis was reduced in sterile conditions
dMPH.e3.AITCsteam.root <- filter(MPH.e3.root,str_detect(Treatment2,'control'))$MPH - 
  filter(MPH.e3.root,str_detect(Treatment2,'AITC'))$MPH
dMPH.e3.AITCsteam.shoot <- filter(MPH.e3.shoot,str_detect(Treatment2,'control'))$MPH - 
  filter(MPH.e3.shoot,str_detect(Treatment2,'AITC'))$MPH
dMPH.e3.chloropicrin.root <- filter(MPH.e3.root,str_detect(Treatment2,'control'))$MPH - 
  filter(MPH.e3.root,str_detect(Treatment2,'chloropicrin'))$MPH
dMPH.e3.chloropicrin.shoot <- filter(MPH.e3.shoot,str_detect(Treatment2,'control'))$MPH - 
  filter(MPH.e3.shoot,str_detect(Treatment2,'chloropicrin'))$MPH
# IS this significantly higher than 0? 
# Permute "treatment" to generate null distribution of dMPH
# Followed by one-tail test

nPerm = 999
for (i in 1:nPerm) {
  print(paste0('Beginning simulation number ',i))
  set.seed(i) # seed the RNG
  for (treat in c('AITC_steam','chloropicrin')) {
    # subset to only include control + 1 fumigated treatment, then permute Treatment:
    e3.perm <- filter(e3.biomass,Treatment%in%c('control',treat)) %>%
      mutate(Treatment.perm = sample(Treatment,size=length(Treatment),replace=FALSE))
    # fit same models used above:
    perm.m1.e3root <- lmer(root_dry_weight_g ~ Genotype*Treatment.perm + (1|Block)+ (1|Sub_block),data=e3.perm) # linear mixed model
    perm.m1.e3shoot <- lmer(shoot_dry_weight_g ~ Genotype*Treatment.perm + (1|Block)+ (1|Sub_block),data=e3.perm) # linear mixed model
    # use EM means to calculate MPH for this permutation
    perm.MPH.e3root <- emmeans(perm.m1.e3root, 'Genotype',by='Treatment.perm') %>%
      as.data.frame() %>%
      select(Genotype,Treatment.perm,emmean) %>%
      pivot_wider(names_from=Genotype,values_from=emmean) %>%
      mutate(inbredMean = (B73+Mo17)/2,
             MPH = (B73xMo17-inbredMean)/inbredMean)
    perm.MPH.e3shoot <- emmeans(perm.m1.e3shoot, 'Genotype',by='Treatment.perm') %>%
      as.data.frame() %>%
      select(Genotype,Treatment.perm,emmean) %>%
      pivot_wider(names_from=Genotype,values_from=emmean) %>%
      mutate(inbredMean = (B73+Mo17)/2,
             MPH = (B73xMo17-inbredMean)/inbredMean)
    # calculate delta MPH for this permutation
    perm.dMPH.e3root <- filter(perm.MPH.e3root,Treatment.perm=='control')$MPH - 
      filter(perm.MPH.e3root,Treatment.perm==treat)$MPH
    perm.dMPH.e3shoot <- filter(perm.MPH.e3shoot,Treatment.perm=='control')$MPH - 
      filter(perm.MPH.e3shoot,Treatment.perm==treat)$MPH
    # save results
    if (i==1 & treat=='AITC_steam') {perm.dMPH.e3.biomass <- data.frame('contrast'=treat, 'perm.dMPH.root'=perm.dMPH.e3root,'perm.dMPH.shoot'=perm.dMPH.e3shoot)}
    else {perm.dMPH.e3.biomass <- rbind(perm.dMPH.e3.biomass, data.frame('contrast'=treat, 'perm.dMPH.root'=perm.dMPH.e3root,'perm.dMPH.shoot'=perm.dMPH.e3shoot))}
  }
}
# How many of the permuted dMPH values are at least as large as the observed value?
## AITC+steam vs. untreated:
filter(perm.dMPH.e3.biomass,contrast=='AITC_steam',perm.dMPH.root>=dMPH.e3.AITCsteam.root) %>% dim() # roots: 84 --> P = 0.084
filter(perm.dMPH.e3.biomass,contrast=='AITC_steam',perm.dMPH.shoot>=dMPH.e3.AITCsteam.shoot) %>% dim() # shoots: 164 --> P = 0.164
## Chloropicrin vs. untreated:
filter(perm.dMPH.e3.biomass,contrast=='chloropicrin',perm.dMPH.root>=dMPH.e3.chloropicrin.root) %>% dim() # roots: 11 --> P = 0.011
filter(perm.dMPH.e3.biomass,contrast=='chloropicrin',perm.dMPH.shoot>=dMPH.e3.chloropicrin.shoot) %>% dim() # shoots: 301 --> P = 0.301

# Plot the results:- biomas
pdf(file='e3_perm_root_AITCsteam.pdf',width=4,height=4)
filter(perm.dMPH.e3.biomass,contrast=='AITC_steam') %>%
  ggplot(aes(x=perm.dMPH.root))+
  geom_histogram()+
  geom_vline(xintercept=dMPH.e3.AITCsteam.root,color='red',size=1.5,linetype='dashed')+
  ggtitle('Root biomass: Untreated field soil vs.\nAITC+steam fumigation')+
  ylab('')+xlab('MPH in nonsterile conditions \n - MPH in sterile conditions')+
  theme_classic()+
  theme(axis.text=element_text(size=12),axis.title=element_text(size=14))
dev.off()

pdf(file='e3_perm_root_chloropicrin.pdf',width=4,height=4)
filter(perm.dMPH.e3.biomass,contrast=='chloropicrin') %>%
  ggplot(aes(x=perm.dMPH.root))+
  geom_histogram()+
  geom_vline(xintercept=dMPH.e3.chloropicrin.root,color='red',size=1.5,linetype='dashed')+
  ggtitle('Root biomass: Untreated field soil vs.\nchloropicrin fumigation')+
  ylab('')+xlab('MPH in nonsterile conditions \n - MPH in sterile conditions')+
  theme_classic()+
  theme(axis.text=element_text(size=12),axis.title=element_text(size=14))
dev.off()

# Clean up:
rm(perm.dMPH.e3,perm.dMPH.e3root,perm.m1.e3root,perm.MPH.e3root,perm.dMPH.e3shoot,perm.m1.e3shoot,perm.MPH.e3shoot)
rm(MPH.e3.root,MPH.e3.shoot,dMPH.e3.AITCsteam.root,dMPH.e3.AITCsteam.shoot,dMPH.e3.chloropicrin.root,dMPH.e3.chloropicrin.shoot)

####### $$$ Expt 3 - permutation tests for strength of midparent heterosis - leaf number #######
# Calculate midparent heterosis in each treatment:
MPH.e3.leafN <- emmeans(m1.e3leafN, 'Genotype',by='Treatment2') %>%
  as.data.frame() %>%
  select(Genotype,Treatment2,emmean) %>%
  pivot_wider(names_from=Genotype,values_from=emmean) %>%
  mutate(inbredMean = (B73+Mo17)/2,
         MPH = (B73xMo17-inbredMean)/inbredMean)
# Calculate "Delta MPH" (MPH in nonsterile - MPH in each sterile treatment)
# Positive dMPH = heterosis was reduced in sterile conditions
dMPH.e3.AITCsteam.leafN <- filter(MPH.e3.leafN,str_detect(Treatment2,'control'))$MPH - 
  filter(MPH.e3.leafN,str_detect(Treatment2,'AITC +'))$MPH
dMPH.e3.AITC.leafN <- filter(MPH.e3.leafN,str_detect(Treatment2,'control'))$MPH - 
  filter(MPH.e3.leafN,str_detect(Treatment2,'AITC'))$MPH
dMPH.e3.chloropicrin.leafN <- filter(MPH.e3.leafN,str_detect(Treatment2,'control'))$MPH - 
  filter(MPH.e3.leafN,str_detect(Treatment2,'chloropicrin'))$MPH
dMPH.e3.steam.leafN <- filter(MPH.e3.leafN,str_detect(Treatment2,'control'))$MPH - 
  filter(MPH.e3.leafN,str_detect(Treatment2,'steam\nonly'))$MPH
# IS this significantly higher than 0? 
# Permute "treatment" to generate null distribution of dMPH
# Followed by one-tail test

nPerm = 999
for (i in 1:nPerm) {
  print(paste0('Beginning simulation number ',i))
  set.seed(i) # seed the RNG
  for (treat in c('AITC_steam','chloropicrin','AITC_only','steam_only')) {
    # subset to only include control + 1 fumigated treatment, then permute Treatment:
    e3.perm <- filter(e3.leafN,Treatment%in%c('control',treat)) %>%
      mutate(Treatment.perm = sample(Treatment,size=length(Treatment),replace=FALSE))
    # fit same models used above:
    perm.m1.e3leafN <- lmer(N_leaves~Genotype*Treatment.perm*Date + (1|PlantID) + (1|Block) + (1|Sub_block),data=e3.perm) # linear mixed model
    # use EM means to calculate MPH for this permutation
    perm.MPH.e3leafN <- emmeans(perm.m1.e3leafN, 'Genotype',by='Treatment.perm') %>%
      as.data.frame() %>%
      select(Genotype,Treatment.perm,emmean) %>%
      pivot_wider(names_from=Genotype,values_from=emmean) %>%
      mutate(inbredMean = (B73+Mo17)/2,
             MPH = (B73xMo17-inbredMean)/inbredMean)
    # calculate delta MPH for this permutation
    perm.dMPH.e3leafN <- filter(perm.MPH.e3leafN,Treatment.perm=='control')$MPH - 
      filter(perm.MPH.e3leafN,Treatment.perm==treat)$MPH
    # save results
    if (i==1 & treat=='AITC_steam') {perm.dMPH.e3.leaf <- data.frame('contrast'=treat, 'perm.dMPH.leafN'=perm.dMPH.e3leafN)}
    else {perm.dMPH.e3.leaf <- rbind(perm.dMPH.e3.leaf, data.frame('contrast'=treat, 'perm.dMPH.leafN'=perm.dMPH.e3leafN))}
  }
}
# How many of the permuted dMPH values are at least as large as the observed value?
## AITC+steam vs. untreated:
filter(perm.dMPH.e3.leaf,contrast=='AITC_steam',perm.dMPH.leafN>=dMPH.e3.AITCsteam.leafN) %>% dim() # leafNs: 2 --> P = 0.002
## Chloropicrin vs. untreated:
filter(perm.dMPH.e3.leaf,contrast=='chloropicrin',perm.dMPH.leafN>=dMPH.e3.chloropicrin.leafN) %>% dim() # leafNs: 19 --> P = 0.019
## Steam only vs. untreated:
filter(perm.dMPH.e3.leaf,contrast=='steam_only',perm.dMPH.leafN>=dMPH.e3.steam.leafN) %>% dim() # leafNs: 7 --> P = 0.007
## AITC only vs. untreated:
filter(perm.dMPH.e3.leaf,contrast=='AITC_only',perm.dMPH.leafN>=dMPH.e3.AITC.leafN) %>% dim() # leafNs: 21 --> P = 0.021

####### $$$ Expt 3 - permutation tests for strength of midparent heterosis - height #######
# Calculate midparent heterosis in each treatment:
MPH.e3.ht <- emmeans(m1.e3height, 'Genotype',by='Treatment2') %>%
  as.data.frame() %>%
  select(Genotype,Treatment2,emmean) %>%
  pivot_wider(names_from=Genotype,values_from=emmean) %>%
  mutate(inbredMean = (B73+Mo17)/2,
         MPH = (B73xMo17-inbredMean)/inbredMean)
# Calculate "Delta MPH" (MPH in nonsterile - MPH in each sterile treatment)
# Positive dMPH = heterosis was reduced in sterile conditions
dMPH.e3.AITCsteam.ht <- filter(MPH.e3.ht,str_detect(Treatment2,'control'))$MPH - 
  filter(MPH.e3.ht,str_detect(Treatment2,'AITC +'))$MPH
dMPH.e3.AITC.ht <- filter(MPH.e3.ht,str_detect(Treatment2,'control'))$MPH - 
  filter(MPH.e3.ht,str_detect(Treatment2,'AITC\nonly'))$MPH
dMPH.e3.chloropicrin.ht <- filter(MPH.e3.ht,str_detect(Treatment2,'control'))$MPH - 
  filter(MPH.e3.ht,str_detect(Treatment2,'chloropicrin'))$MPH
dMPH.e3.steam.ht <- filter(MPH.e3.ht,str_detect(Treatment2,'control'))$MPH - 
  filter(MPH.e3.ht,str_detect(Treatment2,'steam\nonly'))$MPH
# IS this significantly higher than 0? 
# Permute "treatment" to generate null distribution of dMPH
# Followed by one-tail test

nPerm = 999
for (i in 1:nPerm) {
  print(paste0('Beginning simulation number ',i))
  set.seed(i) # seed the RNG
  for (treat in c('AITC_steam','chloropicrin','AITC_only','steam_only')) {
    # subset to only include control + 1 fumigated treatment, then permute Treatment:
    e3.perm <- filter(e3.height,Treatment%in%c('control',treat)) %>%
      mutate(Treatment.perm = sample(Treatment,size=length(Treatment),replace=FALSE))
    # fit same models used above:
    perm.m1.e3ht <- lmer(Height_cm~Genotype*Treatment.perm*Date + (1|PlantID) + (1|Block) + (1|Sub_block),data=e3.perm) # linear mixed model
    # use EM means to calculate MPH for this permutation
    perm.MPH.e3ht <- emmeans(perm.m1.e3ht, 'Genotype',by='Treatment.perm') %>%
      as.data.frame() %>%
      select(Genotype,Treatment.perm,emmean) %>%
      pivot_wider(names_from=Genotype,values_from=emmean) %>%
      mutate(inbredMean = (B73+Mo17)/2,
             MPH = (B73xMo17-inbredMean)/inbredMean)
    # calculate delta MPH for this permutation
    perm.dMPH.e3ht <- filter(perm.MPH.e3ht,Treatment.perm=='control')$MPH - 
      filter(perm.MPH.e3ht,Treatment.perm==treat)$MPH
    # save results
    if (i==1 & treat=='AITC_steam') {perm.dMPH.e3.ht <- data.frame('contrast'=treat, 'perm.dMPH.ht'=perm.dMPH.e3ht)}
    else {perm.dMPH.e3.ht <- rbind(perm.dMPH.e3.ht, data.frame('contrast'=treat, 'perm.dMPH.ht'=perm.dMPH.e3ht))}
  }
}
# How many of the permuted dMPH values are at least as large as the observed value?
## AITC+steam vs. untreated:
filter(perm.dMPH.e3.ht,contrast=='AITC_steam',perm.dMPH.ht>=dMPH.e3.AITCsteam.ht) %>% dim() # 22 --> P = 0.022
## Chloropicrin vs. untreated:
filter(perm.dMPH.e3.ht,contrast=='chloropicrin',perm.dMPH.ht>=dMPH.e3.chloropicrin.ht) %>% dim() # 4 --> P = 0.004
## Steam only vs. untreated:
filter(perm.dMPH.e3.ht,contrast=='steam_only',perm.dMPH.ht>=dMPH.e3.steam.ht) %>% dim() # 1 --> P = 0.001
## AITC only vs. untreated:
filter(perm.dMPH.e3.ht,contrast=='AITC_only',perm.dMPH.ht>=dMPH.e3.AITC.ht) %>% dim() # 1 --> P = 0.001

####### &&& Expt 3 - soil plate counts (Tang) #######
via <- read.delim('../FieldTrial_Oct2019/viability/Allweeks.txt',sep='\t',header=TRUE)
table(via$Week, via$Treat, via$Depth) # look at replication

m1.V.via <- lm(logCFU ~ Depth*Treat*Week, data=filter(via,Plate=='Vxyl G'))
contrast(emtrends(m1.V.via, 'Treat',var='Week',by='Depth'),'dunnett',ref=5)

m1.R.via <- lm(logCFU ~ Depth*Treat*Week, data=filter(via,Plate=='R2A'))
contrast(emtrends(m1.R.via, 'Treat',var='Week',by='Depth'),'dunnett',ref=5)

pdf(file='e3_soilVia.pdf',width=9,height=6)
mutate(via,Treat=plyr::mapvalues(Treat,from=c('AITC','AITC_STE','STE','STND','UT'),to=c('AITC','AITC+Steam','Steam','Chloropicrin','Untreated')),
       Depth=plyr::mapvalues(Depth,from=c('S','D'),to=c(' 3-5 cm','17-20 cm'))) %>%
  ggplot(.,aes(x=Week,y=logCFU,color=Treat))+
  facet_grid(Depth~Plate)+
  xlab('Weeks post treatment')+
  ylab('log(CFU per g soil)')+
  geom_point(alpha=0.3,position=position_jitter(width=0.2))+
  stat_smooth(method='lm',formula='y~x', se=FALSE)+
  theme_classic()+
  scale_color_manual(values=c('goldenrod','forest green','blue','magenta','black'))+
  theme(strip.background=element_rect(fill='grey77'),strip.text=element_text(face='bold',size=12),
        legend.title=element_blank(),legend.text=element_text(size=12),legend.position='right',axis.title=element_text(face='bold',size=14))
dev.off()